@@ -20,7 +20,7 @@
 #' @param start_date Leave blank if all dates are required. Date format needs to be in YYYY-MM-DD. Date is inclusive.
 #' @param end_date Leave blank if all dates are required. Date format needs to be in YYYY-MM-DD. Date is inclusive.
 #'
-#' @return A tibble of monthly levels. 
+#' @return A tibble of monthly levels.
 #'
 #' @format A tibble with 8 variables:
 #' \describe{
@@ -29,19 +29,21 @@
 #'   \item{Month}{Numeric month value}
 #'   \item{Full_month}{Logical value is there is full record from Month}
 #'   \item{No_days}{Number of days in that month}
-#'   \item{Sum_stat}{Summary statistic being used.} 
+#'   \item{Sum_stat}{Summary statistic being used.}
 #'   \item{Value}{Value of the measurement in metres.}
-#'   \item{Date_occurred}{Observation date. Formatted as a Date class. MEAN is a annual summary 
+#'   \item{Date_occurred}{Observation date. Formatted as a Date class. MEAN is a annual summary
 #'   and therefore has an NA value for Date.}
 #' }
 #'
 #' @examples
 #' \dontrun{
-#' hy_monthly_levels(station_number = c("02JE013","08MF005"), 
-#'   start_date = "1996-01-01", end_date = "2000-01-01")
+#' hy_monthly_levels(
+#'   station_number = c("02JE013", "08MF005"),
+#'   start_date = "1996-01-01", end_date = "2000-01-01"
+#' )
 #'
 #' hy_monthly_levels(prov_terr_state_loc = "PE")
-#'           }
+#' }
 #' @family HYDAT functions
 #' @source HYDAT
 #' @export
@@ -49,14 +51,13 @@
 
 
 hy_monthly_levels <- function(station_number = NULL,
-                           hydat_path = NULL,
-                           prov_terr_state_loc = NULL, 
-                           start_date =NULL, 
-                           end_date = NULL) {
-
+                              hydat_path = NULL,
+                              prov_terr_state_loc = NULL,
+                              start_date = NULL,
+                              end_date = NULL) {
   ## Determine which dates should be queried
   dates_null <- date_check(start_date, end_date)
-  
+
   ## Read in database
   hydat_con <- hy_src(hydat_path)
   if (!dplyr::is.src(hydat_path)) {
@@ -65,7 +66,7 @@ hy_monthly_levels <- function(station_number = NULL,
 
   ## Determine which stations we are querying
   stns <- station_choice(hydat_con, station_number, prov_terr_state_loc)
-  
+
   ## Creating rlang symbols
   sym_YEAR <- sym("YEAR")
   sym_STATION_NUMBER <- sym("STATION_NUMBER")
@@ -78,43 +79,46 @@ hy_monthly_levels <- function(station_number = NULL,
   monthly_levels <- dplyr::filter(monthly_levels, !!sym_STATION_NUMBER %in% stns)
 
   ## Do the initial subset to take advantage of dbplyr only issuing sql query when it has too
-  
+
   ## by year
   if (!dates_null[["start_is_null"]]) monthly_levels <- dplyr::filter(monthly_levels, !!sym_YEAR >= lubridate::year(start_date))
   if (!dates_null[["end_is_null"]]) monthly_levels <- dplyr::filter(monthly_levels, !!sym_YEAR <= lubridate::year(end_date))
 
-  monthly_levels <- dplyr::select(monthly_levels, .data$STATION_NUMBER:.data$MAX)
+  monthly_levels <- dplyr::select(monthly_levels, STATION_NUMBER:MAX)
   monthly_levels <- dplyr::collect(monthly_levels)
-  
-  if(is.data.frame(monthly_levels) && nrow(monthly_levels)==0)
-  {stop("This station is not present in HYDAT")}
-  
-  ## Need to rename columns for gather
-  colnames(monthly_levels) <- c("STATION_NUMBER","Year","Month", "PRECISION_CODE", "Full_month", "No_days", "MEAN_Value",
-                           "TOTAL_Value", "MIN_DAY","MIN_Value", "MAX_DAY","MAX_Value")
-  
-  
 
-  monthly_levels <- tidyr::gather(monthly_levels, !!sym_variable, !!sym_temp, -(.data$STATION_NUMBER:.data$No_days))
-  monthly_levels <- tidyr::separate(monthly_levels, !!sym_variable, into = c("Sum_stat","temp2"), sep = "_")
+  if (is.data.frame(monthly_levels) && nrow(monthly_levels) == 0) {
+    stop("This station is not present in HYDAT")
+  }
+
+  ## Need to rename columns for gather
+  colnames(monthly_levels) <- c(
+    "STATION_NUMBER", "Year", "Month", "PRECISION_CODE", "Full_month", "No_days", "MEAN_Value",
+    "TOTAL_Value", "MIN_DAY", "MIN_Value", "MAX_DAY", "MAX_Value"
+  )
+
+
+
+  monthly_levels <- tidyr::gather(monthly_levels, !!sym_variable, !!sym_temp, -(STATION_NUMBER:No_days))
+  monthly_levels <- tidyr::separate(monthly_levels, !!sym_variable, into = c("Sum_stat", "temp2"), sep = "_")
 
   monthly_levels <- tidyr::spread(monthly_levels, !!sym_temp2, !!sym_temp)
 
   ## convert into R date for date of occurence.
-  monthly_levels <- dplyr::mutate(monthly_levels, Date_occurred = paste0(.data$Year, "-", .data$Month, "-", .data$DAY))
-  
-  ## Check if DAY is NA and if so give it an NA value so the date parse correctly.
-  monthly_levels <- dplyr::mutate(monthly_levels, Date_occurred = ifelse(is.na(.data$DAY), NA, .data$Date_occurred))
-  monthly_levels <- dplyr::mutate(monthly_levels, Date_occurred = lubridate::ymd(.data$Date_occurred, quiet = TRUE))
-  
-  ## Then when a date column exist fine tune the subset
-  if (!dates_null[["start_is_null"]]) monthly_levels <- dplyr::filter(monthly_levels, .data$Date_occurred >= start_date)
-  if (!dates_null[["end_is_null"]]) monthly_levels <- dplyr::filter(monthly_levels, .data$Date_occurred <= end_date)
+  monthly_levels <- dplyr::mutate(monthly_levels, Date_occurred = paste0(Year, "-", Month, "-", DAY))
 
-  monthly_levels <- dplyr::select(monthly_levels, -.data$DAY)
-  monthly_levels <- dplyr::mutate(monthly_levels, Full_month = .data$Full_month == 1)
-  
-  
-  attr(monthly_levels,'missed_stns') <- setdiff(unique(stns), unique(monthly_levels$STATION_NUMBER))
+  ## Check if DAY is NA and if so give it an NA value so the date parse correctly.
+  monthly_levels <- dplyr::mutate(monthly_levels, Date_occurred = ifelse(is.na(DAY), NA, Date_occurred))
+  monthly_levels <- dplyr::mutate(monthly_levels, Date_occurred = lubridate::ymd(Date_occurred, quiet = TRUE))
+
+  ## Then when a date column exist fine tune the subset
+  if (!dates_null[["start_is_null"]]) monthly_levels <- dplyr::filter(monthly_levels, Date_occurred >= start_date)
+  if (!dates_null[["end_is_null"]]) monthly_levels <- dplyr::filter(monthly_levels, Date_occurred <= end_date)
+
+  monthly_levels <- dplyr::select(monthly_levels, -DAY)
+  monthly_levels <- dplyr::mutate(monthly_levels, Full_month = Full_month == 1)
+
+
+  attr(monthly_levels, "missed_stns") <- setdiff(unique(stns), unique(monthly_levels$STATION_NUMBER))
   as.hy(monthly_levels)
 }
